@@ -40,6 +40,30 @@ class ObjectView(BrowserView):
 	else:
 		return desc
 
+    def getMedia(self, item, scale="large"):
+	""" finds and returns relevant leading media for the context item
+	"""
+	if item.portal_type == 'Image':
+	    return item.absolute_url() + '/image_%s'%scale
+	
+	catalog = getToolByName(self.context, 'portal_catalog')
+	plone_utils = getToolByName(self.context, 'plone_utils')
+	path = '/'.join(item.getPhysicalPath())
+	
+	if plone_utils.isStructuralFolder(item):
+	    results = catalog.searchResults(path = {'query' : path,'depth' : 1 }, type = ['Image'], sort_on = 'getObjPositionInParent')
+	    if len(results) > 0:
+		leadMedia = results[0]
+		if leadMedia.portal_type == 'Image':
+		    return leadMedia.getURL() + '/image_%s'%scale
+		else:
+		    return None
+	    else:
+		return None
+	else:
+	    #TODO: Add lead image support and News Item Image support
+	    return None
+
     def getTileMedia(self, item):
 	catalog = getToolByName(self, 'portal_catalog')
 	try:
