@@ -1,5 +1,5 @@
 from plone.i18n.normalizer import idnormalizer
-
+from zope.app.component.hooks import getSite
 
 from Products.CMFCore.utils import getToolByName
         
@@ -7,14 +7,14 @@ def objectModified(object, event):
     """
     Object was added, check for images and add them;
     """
-    print "REQUEST OBJECT %s MODIFIED"%(object.id)
+    #print "REQUEST OBJECT %s MODIFIED"%(object.id)
     
     for i in range(1,4):
         if hasattr(object.REQUEST, 'image%s'%i) and object.REQUEST['image%s'%i][0]:
             id = idnormalizer.normalize(unicode(object.REQUEST['image%s'%i][0].filename, "utf-8"))
             
             if not hasattr(object, id):
-                print "id is new"
+                #print "id is new"
             
                 object.invokeFactory(
                         type_name="Image",
@@ -29,8 +29,13 @@ def objectModified(object, event):
                 
                 #item1.processForm()
             
-        else:
-            print "empty file"
-        
-    
-        
\ No newline at end of file
+        #else:
+            #print "empty file"
+            
+    #Publish member folder automatically
+    parent = object.aq_parent
+    portal = getSite()
+    wtool = getToolByName(portal, "portal_workflow")
+    if wtool.getInfoFor(parent, 'review_state', '') != 'published':
+        wtool.doActionFor(parent, "publish", comment="Content automatically published")
+    
\ No newline at end of file
